@@ -261,7 +261,7 @@ def split_overlength_bert_input_sequence(sequence: Union[str, List[str]],
         raise TypeError("Input parameter `sequence` has Unknown type.")
 
     tks = merge_list_of_lists(tks_seq_list)
-    if len(tokenizer.tokenize(' '.join(tks), add_special_tokens=True)) < max_seq_length:
+    if len(tokenizer.tokenize(tks, add_special_tokens=True, is_split_into_words=True)) <= max_seq_length:
         return [sequence]
 
     if isinstance(sequence, list):
@@ -269,7 +269,7 @@ def split_overlength_bert_input_sequence(sequence: Union[str, List[str]],
                                           "Consider assigning values to `sent_lens` to disable " \
                                           "automatic sentence tokenization!"
 
-    seq_bert_len_list = [len(tokenizer.tokenize(' '.join(tks_seq), add_special_tokens=True))
+    seq_bert_len_list = [len(tokenizer.tokenize(tks_seq, add_special_tokens=True, is_split_into_words=True))
                          for tks_seq in tks_seq_list]
 
     assert (np.asarray(seq_bert_len_list) <= max_seq_length).all(), \
@@ -302,7 +302,7 @@ def split_overlength_bert_input_sequence(sequence: Union[str, List[str]],
     return split_tks_seq_list
 
 
-def substitute_unknown_tokens(tk_seq: List[str], tokenizer, unk_tag: Optional[str] = '[UNK]') -> List[str]:
+def substitute_unknown_tokens(tk_seq: List[str], tokenizer) -> List[str]:
     """
     Substitute the tokens in tk_seq unknown to the tokenizer by `unk_tag`
 
@@ -310,7 +310,6 @@ def substitute_unknown_tokens(tk_seq: List[str], tokenizer, unk_tag: Optional[st
     ----------
     tk_seq: a list (sequence) of tokens
     tokenizer: a loaded BERT tokenizer
-    unk_tag: the tag represents unknown tokens
 
     Returns
     -------
@@ -324,7 +323,7 @@ def substitute_unknown_tokens(tk_seq: List[str], tokenizer, unk_tag: Optional[st
 
     for ori_idx, bert_tk_ids in enumerate(ori2bert):
         if not bert_tk_ids:
-            tks[ori_idx] = unk_tag
+            tks[ori_idx] = tokenizer.unk_token
 
     return tks
 
